/* ********************************************* */
//
// ACES IDT for Canon EOS C500 (Type D)
//
// IDT for C500 Cinema Gamut
// Version: 1.1  2013/11/11
// Copyright(c) 2013 Canon Inc. All Rights Reserved.
//
/* ********************************************* */
//
// Camera     : EOS C500
// Output     : 3G-SDI 1 and 2, Cinema RAW(.rmf) file, Mon.1 and 2
// Illuminant : Tungsten (ISO 7589 Studio Tungsten)
// Color Gamut: Cinema Gamut
//
// [ NOTE ]                          
//
// +This IDT is defined for images those were shot under
//  illumination sources with low color temperature like Tungsten. 
//
// +This IDT can be applied for the images from 3G-SDI 1 / 2,
//  Cinema RAW(.rmf) file or Mon.1 / 2.
//
// +Different IDT should be refered for MXF file and other outputs
//  such as HD-SDI / HDMI.
// 
/* ********************************************* */


/* ============ SUBFUNCTIONS ============ */
/* CanonLog IRE to Linear */
float CanonLog_to_linear (
	float clog_ire
)
{
	return (pow(10,(clog_ire-0.0730597)/0.529136)-1)/10.1596;

}


/* ============ Main Algorithm ============ */
void main
(   input varying float rIn,
    input varying float gIn,
    input varying float bIn,
    input varying float aIn,
    output varying float rOut,
    output varying float gOut,
    output varying float bOut,
    output varying float aOut
)
{
	// CodeValue to IRE, ire = (cv-64)/(940-64)
	float CLogIRE[3];
	CLogIRE[0] = (rIn*1023 - 64) / 876;
	CLogIRE[1] = (gIn*1023 - 64) / 876;
	CLogIRE[2] = (bIn*1023 - 64) / 876;

	// Canon-Log to linear 
	float lin[3];
	lin[0] = 0.9 * CanonLog_to_linear( CLogIRE[0]);
	lin[1] = 0.9 * CanonLog_to_linear( CLogIRE[1]);
	lin[2] = 0.9 * CanonLog_to_linear( CLogIRE[2]);
	
	// ACES conversion matrix
	float aces[3];

	aces[0] = 0.817416293 * lin[0] +0.090755698 * lin[1] + 0.091828009 * lin[2];
	aces[1] =-0.035361374 * lin[0] +1.065690585 * lin[1] - 0.030329211 * lin[2];
	aces[2] = 0.010390366 * lin[0] -0.299271107 * lin[1] + 1.288880741 * lin[2];



	rOut = aces[0];
	gOut = aces[1];
	bOut = aces[2];
	aOut = aIn;
}


/* ============ End of IDT ============ */

