/* ********************************************* */
//
// ACES IDT for Canon EOS C500 (Type C)
//
// IDT for C500 DCI-P3+ Gamut
// Version: 1.1  2013/11/11
// Copyright(c) 2013 Canon Inc. All Rights Reserved.
//
/* ********************************************* */
//
// Camera     : EOS C500
// Output     : 3G-SDI 1 and 2, Cinema RAW(.rmf) file, Mon.1 and 2
// Illuminant : Daylight (CIE Illuminant D55)
// Color Gamut: DCI-P3+
//
// [ NOTE ]                          
//
// +This IDT is defined for images those were shot under daylight
//  and general illumination sources except Tungsten.
//
// +This IDT can be applied for the images from 3G-SDI 1 / 2,
//  Cinema RAW(.rmf) file or Mon.1 / 2.
//
// +Different IDT should be refered for MXF file and other outputs
//  such as HD-SDI / HDMI.
// 
/* ********************************************* */


/* ============ SUBFUNCTIONS ============ */
/* CanonLog IRE to Linear */
float CanonLog_to_linear (
	float clog_ire
)
{
	return (pow(10,(clog_ire-0.0730597)/0.529136)-1)/10.1596;

}


/* ============ Main Algorithm ============ */
void main
(   input varying float rIn,
    input varying float gIn,
    input varying float bIn,
    input varying float aIn,
    output varying float rOut,
    output varying float gOut,
    output varying float bOut,
    output varying float aOut
)
{
	// CodeValue to IRE, ire = (cv-64)/(940-64)
	float CLogIRE[3];
	CLogIRE[0] = (rIn*1023 - 64) / 876;
	CLogIRE[1] = (gIn*1023 - 64) / 876;
	CLogIRE[2] = (bIn*1023 - 64) / 876;

	// Canon-Log to linear 
	float lin[3];
	lin[0] = 0.9 * CanonLog_to_linear( CLogIRE[0]);
	lin[1] = 0.9 * CanonLog_to_linear( CLogIRE[1]);
	lin[2] = 0.9 * CanonLog_to_linear( CLogIRE[2]);
	
	// ACES conversion matrix
	float aces[3];

	aces[0] = 0.607160575 * lin[0] +0.299507286 * lin[1] + 0.093332140 * lin[2];
	aces[1] = 0.004968120 * lin[0] +1.050982224 * lin[1] - 0.055950343 * lin[2];
	aces[2] =-0.007839939 * lin[0] +0.000809127 * lin[1] + 1.007030813 * lin[2];



	rOut = aces[0];
	gOut = aces[1];
	bOut = aces[2];
	aOut = aIn;
}

/* ============ End of IDT ============ */

